@@ -18,7 +18,7 @@ require 5.004;
 
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = '0.35';
+$VERSION = '0.36';
 
 ######################################################################
 
@@ -616,7 +616,7 @@ sub _send_email_message {
 	
 	my $body_header = <<__endquote.
 --------------------------------------------------
-This e-mail was sent at @{[$globals->today_date_utc()]} 
+This e-mail was sent at @{[$self->_today_date_utc()]} 
 by the web site "@{[$globals->site_title()]}", 
 which is located at "@{[$globals->base_url()]}".
 __endquote
@@ -690,6 +690,16 @@ __endquote
 
 ######################################################################
 
+sub _today_date_utc {
+	my ($sec, $min, $hour, $mday, $mon, $year) = gmtime(time);
+	$year += 1900;  # year counts from 1900 AD otherwise
+	$mon += 1;      # ensure January is 1, not 0
+	my @parts = ($year, $mon, $mday, $hour, $min, $sec);
+	return( sprintf( "%4.4d-%2.2d-%2.2d %2.2d:%2.2d:%2.2d UTC", @parts ) );
+}
+
+######################################################################
+
 1;
 __END__
 
